"""
 htyy
~~~~~~
Version: 0.1.3
"""

from . import client
from . import reponse
from . import extensions
from . import request
from . import version
from . import message
from . import _path
from .windll import windll, platform
from .pyos import *
from . import pyos, hpyy
from ._infront._htyy_d import (
    combination, cos, cosh, cot, ComplexNumber,
    AdminPrivilegeChecker, exp, sha1, sha224,
    sha256, sha384, sha3_256, sha3_384, sha3_512,
    sha512, shake_128, shake_256, sin, sinh, sqrt,
    factorial, floor, blake2b, blake2s, absolute_value,
    tan, tanh, pi, power, md5, ln, log10, cmd, HF,
    WithHtyy, HtyySet, HtNone, HLen
)
from . import websys, winp
from . import _h7z as h7z, _system as temsys
from . import gui
import logging, os, winreg
from pathlib import Path
import warnings

class HtyyWarning(Warning):
    pass

class HtyyTqdmWarning(HtyyWarning):
    pass

try:
    import tqdm
except:
    warnings.warn(
        "The tqdm library is not detected and some features may be limited. Please run 'pip install tqdm' to install.",
        HtyyTqdmWarning,
        stacklevel=2
    )

__version__ = version.__version__

import miniaudio
import pyaudio
import threading
import time
import numpy as np

class Music:
    def __init__(self, file_path, play_time=-1):
        self.file_path = file_path
        self.play_time = play_time
        self._running = False
        self.audio_thread = None
        self._load_audio()  # 加载音频
        self.play()

    def _load_audio(self):
        """使用 miniaudio 加载音频"""
        try:
            # 解码音频文件（默认输出为 16 位整数）
            decoded = miniaudio.decode_file(self.file_path)
            self.sample_rate = decoded.sample_rate
            self.channels = decoded.nchannels
            # 将数据转换为 numpy 数组（int16）
            self.audio_data = np.frombuffer(decoded.samples, dtype=np.int16)
        except Exception as e:
            raise ValueError(f"Failed to load audio:{e}")

    def _play_audio(self):
        """核心播放逻辑"""
        p = pyaudio.PyAudio()
        stream = p.open(
            format=pyaudio.paInt16,  # 指定 16 位整数格式
            channels=self.channels,
            rate=self.sample_rate,
            output=True
        )

        self._running = True
        start_time = time.time()
        pos = 0
        chunk_size = 1024  # 每次写入的帧数

        while self._running and pos < len(self.audio_data):
            if self.play_time > 0 and (time.time() - start_time) >= self.play_time:
                break

            end_pos = pos + chunk_size * self.channels  # 注意：每个帧包含多个通道的数据
            chunk = self.audio_data[pos:end_pos]
            stream.write(chunk.tobytes())
            pos = end_pos

        stream.stop_stream()
        stream.close()
        p.terminate()

    def play(self):
        if not self._running:
            self.audio_thread = threading.Thread(target=self._play_audio)
            self.audio_thread.start()

    def stop(self):
        self._running = False
        if self.audio_thread and self.audio_thread.is_alive():
            self.audio_thread.join()

from PIL import Image

class ImageConversionError(Exception):
    """自定义图像转换异常"""
    pass

class ImageConversion:
    SUPPORTED_FORMATS = {
        "jpg": "JPEG",
        "jpeg": "JPEG",
        "png": "PNG",
        "bmp": "BMP",
        "webp": "WEBP",
        "gif": "GIF",
        "tiff": "TIFF"
    }

    def __init__(self, input_path: str, output_path: str, **kwargs):
        """
        初始化图像转换器
        :param input_path:  输入图像路径（如 "D:/input.jpg"）
        :param output_path: 输出图像路径（如 "D:/output.png"）
        :param kwargs:      可选参数（如 quality=85, optimize=True）
        """
        self.input_path = Path(input_path).resolve()
        self.output_path = Path(output_path).resolve()
        self.convert_params = kwargs  # 转换参数（如质量、优化选项）
        self._validate_paths()
        logging.basicConfig(level=logging.INFO)

    def _validate_paths(self):
        """验证输入输出路径合法性"""
        # 输入文件检查
        if not self.input_path.exists():
            raise FileNotFoundError(f"The input file does not exist: {self.input_path}")
        
        # 输入格式支持性检查
        input_ext = self.input_path.suffix.lower()[1:]
        if input_ext not in self.SUPPORTED_FORMATS:
            raise ValueError(f"Unsupported input formats: .{input_ext}")

        # 输出目录写入权限检查
        output_dir = self.output_path.parent
        output_dir.mkdir(parents=True, exist_ok=True)
        if not os.access(str(output_dir), os.W_OK):
            raise PermissionError(f"No write permissions: {output_dir}")

        # 输出格式支持性检查
        output_ext = self.output_path.suffix.lower()[1:]
        if output_ext not in self.SUPPORTED_FORMATS:
            raise ValueError(f"Unsupported output formats: .{output_ext}")

    def _get_save_params(self) -> dict:
        """根据输出格式生成保存参数"""
        output_ext = self.output_path.suffix.lower()[1:]
        params = self.convert_params.copy()

        # 格式特定参数（示例：JPEG 质量、PNG 压缩）
        if output_ext in ["jpg", "jpeg"]:
            params.setdefault("quality", 90)  # 默认 JPEG 质量 90%
        elif output_ext == "webp":
            params.setdefault("quality", 80)  # 默认 WEBP 质量 80%
        elif output_ext == "png":
            params.setdefault("compress_level", 6)  # PNG 压缩级别

        return params

    def convert(self):
        """执行图像格式转换"""
        try:
            # 打开输入图像
            with Image.open(self.input_path) as img:
                # 转换 RGBA 格式处理（如 PNG 转 JPEG 需移除透明度）
                if img.mode in ("RGBA", "LA") and self.output_path.suffix.lower() in [".jpg", ".jpeg"]:
                    background = Image.new("RGB", img.size, (255, 255, 255))
                    background.paste(img, mask=img.split()[-1])  # 移除透明度
                    img = background

                # 保存为输出格式
                img.save(
                    self.output_path,
                    format=self.SUPPORTED_FORMATS[self.output_path.suffix.lower()[1:]],
                    **self._get_save_params()
                )
            
            logging.info(f"The conversion was successful: {self.output_path}")

        except IOError as e:
            error_msg = f"Image processing failed: {str(e)}"
            logging.error(error_msg)
            raise ImageConversionError(error_msg)
        except Exception as e:
            logging.error(f"Error: {str(e)}")
            raise

"""
if __name__ == "__main__":
    try:
        converter = VideoConversion(
            input_path="D:/test_video.mp4",
            output_path="D:/output/test_audio.wav"
        )
        converter.convert()
    except Exception as e:
        print(f"转换失败: {str(e)}")
        sys.exit(1)
"""

path = _path
htyy = __file__
import sys
_names = sys.builtin_module_names

if _names == "nt":
    name = "win32"

elif _names == "posix":
    name = "posix"

else:
    name = _names

from ._a import compile_c_to_pyd
_ = name

import os
import subprocess
import tempfile
import datetime
import platform
from typing import Union, Tuple, Optional

class PowerShellFileTimeSetter:
    def __init__(
        self, 
        file_path: str,
        creation_time: Optional[Union[datetime.datetime, str]] = None,
        last_write_time: Optional[Union[datetime.datetime, str]] = None,
        last_access_time: Optional[Union[datetime.datetime, str]] = None,
        default_time: Union[datetime.datetime, str] = datetime.datetime(1980, 1, 1)
    ):
        """
        初始化文件时间设置器
        
        参数:
            file_path (str): 要修改的文件路径
            creation_time (datetime/str): 文件的创建时间，可以是datetime对象或"YYYY-MM-DD HH:MM:SS"字符串
            last_write_time (datetime/str): 文件的修改时间
            last_access_time (datetime/str): 文件的访问时间
            default_time (datetime/str): 默认时间（当其他时间未提供或无效时使用）
        
        # 示例1：在初始化时设置所有时间
        print("示例1: 在初始化时设置所有时间")
        setter1 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            creation_time="1111-11-11 11:11:11",
            last_write_time="2222-02-22 22:22:22",
            last_access_time="3333-03-33 03:33:33"  # 这个时间无效，将使用默认时间
        )
        print(setter1)
        success, output = setter1.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        
        # 示例2：使用默认时间
        print("\n示例2: 使用默认时间")
        setter2 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            default_time="1999-12-31 23:59:59"
        )
        print(setter2)
        success, output = setter2.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        
        # 示例3：使用set_all_times_to方法
        print("\n示例3: 使用set_all_times_to方法")
        setter3 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            default_time="2000-01-01"
        )
        setter3.set_all_times_to("2025-06-10 12:00:00")
        print(setter3)
        success, output = setter3.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        
        # 示例4：使用datetime对象
        print("\n示例4: 使用datetime对象")
        custom_time = datetime.datetime(2100, 12, 31, 23, 59, 59)
        setter4 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            creation_time=custom_time,
            last_write_time=custom_time
        )
        print(setter4)
        success, output = setter4.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        """
        self.file_path = file_path
        self.default_time = self._parse_time(default_time) if isinstance(default_time, str) else default_time
        
        # 解析时间参数
        self.creation_time = self._parse_time(creation_time) if creation_time else self.default_time
        self.last_write_time = self._parse_time(last_write_time) if last_write_time else self.default_time
        self.last_access_time = self._parse_time(last_access_time) if last_access_time else self.default_time
        
        # PowerShell相关变量
        self.temp_script = None
        self.execution_policy_bypassed = False
        self.original_execution_policy = None
        self.is_windows = platform.system() == "Windows"
        
        # 确保文件存在
        if not os.path.exists(self.file_path):
            with open(self.file_path, 'w') as f:
                f.write("Temporary file for time setting")
    
    def _parse_time(self, time_input: Union[datetime.datetime, str]) -> datetime.datetime:
        """解析时间输入（支持datetime对象或字符串）"""
        if isinstance(time_input, datetime.datetime):
            return time_input
        
        try:
            # 尝试解析带时间的字符串格式
            return datetime.datetime.strptime(time_input, "%Y-%m-%d %H:%M:%S")
        except ValueError:
            try:
                # 尝试解析仅日期的字符串格式
                return datetime.datetime.strptime(time_input, "%Y-%m-%d")
            except ValueError:
                # 尝试解析自定义格式
                try:
                    return datetime.datetime.strptime(time_input, "%Y/%m/%d %H:%M:%S")
                except:
                    # 所有尝试失败，使用默认时间
                    return self.default_time
    
    def _escape_path(self, path: str) -> str:
        """转义路径中的特殊字符"""
        return path.replace("'", "''").replace("&", "`&")
    
    def _create_powershell_script(self) -> str:
        """创建 PowerShell 脚本内容"""
        escaped_path = self._escape_path(self.file_path)
        
        script = f"""
# 设置文件时间属性
$file = '{escaped_path}'

# 检查文件是否存在
if (-not (Test-Path -Path $file -PathType Leaf)) {{
    Write-Host "错误: 文件 '$file' 不存在" -ForegroundColor Red
    exit 1
}}

# 创建时间对象
try {{
    $creationDate = [DateTime]::new({self.creation_time.year}, {self.creation_time.month}, {self.creation_time.day}, {self.creation_time.hour}, {self.creation_time.minute}, {self.creation_time.second})
    $writeDate = [DateTime]::new({self.last_write_time.year}, {self.last_write_time.month}, {self.last_write_time.day}, {self.last_write_time.hour}, {self.last_write_time.minute}, {self.last_write_time.second})
    $accessDate = [DateTime]::new({self.last_access_time.year}, {self.last_access_time.month}, {self.last_access_time.day}, {self.last_access_time.hour}, {self.last_access_time.minute}, {self.last_access_time.second})
    
    Write-Host "目标创建时间: $creationDate"
    Write-Host "目标修改时间: $writeDate"
    Write-Host "目标访问时间: $accessDate"
}}
catch {{
    Write-Host "创建日期对象失败: $_" -ForegroundColor Red
    exit 2
}}

# 设置文件时间属性
try {{
    Set-ItemProperty -Path $file -Name CreationTime -Value $creationDate -ErrorAction Stop
    Set-ItemProperty -Path $file -Name LastWriteTime -Value $writeDate -ErrorAction Stop
    Set-ItemProperty -Path $file -Name LastAccessTime -Value $accessDate -ErrorAction Stop
    
    Write-Host "文件时间属性已成功修改!" -ForegroundColor Green
    exit 0
}}
catch {{
    Write-Host "修改文件时间失败: $_" -ForegroundColor Red
    exit 3
}}
"""
        return script
    
    def _save_script_to_tempfile(self, script_content: str) -> str:
        """保存脚本到临时文件"""
        with tempfile.NamedTemporaryFile(suffix='.ps1', delete=False) as temp:
            temp.write(script_content.encode('utf-8'))
            self.temp_script = temp.name
        return self.temp_script
    
    def _get_execution_policy(self) -> Optional[str]:
        """获取当前执行策略"""
        if not self.is_windows:
            return None
            
        try:
            result = subprocess.run(
                ['powershell', '-Command', 'Get-ExecutionPolicy'],
                capture_output=True, text=True, check=True
            )
            return result.stdout.strip()
        except:
            return None
    
    def _set_execution_policy(self, policy: str) -> bool:
        """设置执行策略"""
        if not self.is_windows:
            return False
            
        try:
            subprocess.run(
                ['powershell', '-Command', f'Set-ExecutionPolicy {policy} -Scope CurrentUser -Force'],
                check=True
            )
            return True
        except:
            return False
    
    def _bypass_execution_policy(self) -> bool:
        """临时绕过执行策略限制"""
        if not self.is_windows:
            return False
            
        self.original_execution_policy = self._get_execution_policy()
        if self.original_execution_policy:
            # 临时设置为Bypass
            if self._set_execution_policy('Bypass'):
                self.execution_policy_bypassed = True
                return True
        return False
    
    def _restore_execution_policy(self) -> bool:
        """恢复原始执行策略"""
        if not self.is_windows or not self.execution_policy_bypassed or not self.original_execution_policy:
            return False
            
        return self._set_execution_policy(self.original_execution_policy)
    
    def apply(self) -> Tuple[bool, str]:
        """
        应用设置的时间到文件
        
        返回:
            tuple: (success: bool, output: str)
        """
        if not self.is_windows:
            return False, "此功能仅支持Windows系统"
        
        # 创建PowerShell脚本
        ps_script = self._create_powershell_script()
        script_path = self._save_script_to_tempfile(ps_script)
        
        # 尝试绕过执行策略
        self._bypass_execution_policy()
        
        try:
            # 运行PowerShell脚本
            result = subprocess.run(
                ['powershell', '-ExecutionPolicy', 'Bypass', '-File', script_path],
                capture_output=True, text=True, check=True
            )
            success = result.returncode == 0
            return success, result.stdout
        except subprocess.CalledProcessError as e:
            return False, f"执行错误: {e.stderr}"
        finally:
            # 清理临时文件
            if self.temp_script and os.path.exists(self.temp_script):
                os.remove(self.temp_script)
            
            # 恢复执行策略
            self._restore_execution_policy()
    
    def set_all_times_to(self, target_time: Union[datetime.datetime, str]) -> None:
        """
        设置所有时间属性为同一时间
        
        参数:
            target_time (datetime/str): 目标时间
        """
        parsed_time = self._parse_time(target_time) if isinstance(target_time, str) else target_time
        self.creation_time = parsed_time
        self.last_write_time = parsed_time
        self.last_access_time = parsed_time
    
    def __str__(self) -> str:
        """返回类的字符串表示"""
        return (
            f"FileTimeSetter for: {self.file_path}\n"
            f"  Creation Time: {self.creation_time.strftime('%Y-%m-%d %H:%M:%S')}\n"
            f"  Last Write Time: {self.last_write_time.strftime('%Y-%m-%d %H:%M:%S')}\n"
            f"  Last Access Time: {self.last_access_time.strftime('%Y-%m-%d %H:%M:%S')}"
        )
    
    def __del__(self):
        """析构函数，确保清理"""
        if self.temp_script and os.path.exists(self.temp_script):
            os.remove(self.temp_script)
        if self.execution_policy_bypassed:
            self._restore_execution_policy()

class psfts:
    def __init__(
        self, 
        file_path: str,
        creation_time: Optional[Union[datetime.datetime, str]] = None,
        last_write_time: Optional[Union[datetime.datetime, str]] = None,
        last_access_time: Optional[Union[datetime.datetime, str]] = None,
        default_time: Union[datetime.datetime, str] = datetime.datetime(1980, 1, 1)
    ):
        """
        初始化文件时间设置器
        
        参数:
            file_path (str): 要修改的文件路径
            creation_time (datetime/str): 文件的创建时间，可以是datetime对象或"YYYY-MM-DD HH:MM:SS"字符串
            last_write_time (datetime/str): 文件的修改时间
            last_access_time (datetime/str): 文件的访问时间
            default_time (datetime/str): 默认时间（当其他时间未提供或无效时使用）
        
        # 示例1：在初始化时设置所有时间
        print("示例1: 在初始化时设置所有时间")
        setter1 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            creation_time="1111-11-11 11:11:11",
            last_write_time="2222-02-22 22:22:22",
            last_access_time="3333-03-33 03:33:33"  # 这个时间无效，将使用默认时间
        )
        print(setter1)
        success, output = setter1.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        
        # 示例2：使用默认时间
        print("\n示例2: 使用默认时间")
        setter2 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            default_time="1999-12-31 23:59:59"
        )
        print(setter2)
        success, output = setter2.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        
        # 示例3：使用set_all_times_to方法
        print("\n示例3: 使用set_all_times_to方法")
        setter3 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            default_time="2000-01-01"
        )
        setter3.set_all_times_to("2025-06-10 12:00:00")
        print(setter3)
        success, output = setter3.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        
        # 示例4：使用datetime对象
        print("\n示例4: 使用datetime对象")
        custom_time = datetime.datetime(2100, 12, 31, 23, 59, 59)
        setter4 = PowerShellFileTimeSetter(
            file_path="F:\\hyy&\\pip.txt",
            creation_time=custom_time,
            last_write_time=custom_time
        )
        print(setter4)
        success, output = setter4.apply()
        print("操作成功:", success)
        print("输出结果:", output)
        """
        self.file_path = file_path
        self.default_time = self._parse_time(default_time) if isinstance(default_time, str) else default_time
        
        # 解析时间参数
        self.creation_time = self._parse_time(creation_time) if creation_time else self.default_time
        self.last_write_time = self._parse_time(last_write_time) if last_write_time else self.default_time
        self.last_access_time = self._parse_time(last_access_time) if last_access_time else self.default_time
        
        # PowerShell相关变量
        self.temp_script = None
        self.execution_policy_bypassed = False
        self.original_execution_policy = None
        self.is_windows = platform.system() == "Windows"
        
        # 确保文件存在
        if not os.path.exists(self.file_path):
            with open(self.file_path, 'w') as f:
                f.write("Temporary file for time setting")
    
    def _parse_time(self, time_input: Union[datetime.datetime, str]) -> datetime.datetime:
        """解析时间输入（支持datetime对象或字符串）"""
        if isinstance(time_input, datetime.datetime):
            return time_input
        
        try:
            # 尝试解析带时间的字符串格式
            return datetime.datetime.strptime(time_input, "%Y-%m-%d %H:%M:%S")
        except ValueError:
            try:
                # 尝试解析仅日期的字符串格式
                return datetime.datetime.strptime(time_input, "%Y-%m-%d")
            except ValueError:
                # 尝试解析自定义格式
                try:
                    return datetime.datetime.strptime(time_input, "%Y/%m/%d %H:%M:%S")
                except:
                    # 所有尝试失败，使用默认时间
                    return self.default_time
    
    def _escape_path(self, path: str) -> str:
        """转义路径中的特殊字符"""
        return path.replace("'", "''").replace("&", "`&")
    
    def _create_powershell_script(self) -> str:
        """创建 PowerShell 脚本内容"""
        escaped_path = self._escape_path(self.file_path)
        
        script = f"""
# 设置文件时间属性
$file = '{escaped_path}'

# 检查文件是否存在
if (-not (Test-Path -Path $file -PathType Leaf)) {{
    Write-Host "错误: 文件 '$file' 不存在" -ForegroundColor Red
    exit 1
}}

# 创建时间对象
try {{
    $creationDate = [DateTime]::new({self.creation_time.year}, {self.creation_time.month}, {self.creation_time.day}, {self.creation_time.hour}, {self.creation_time.minute}, {self.creation_time.second})
    $writeDate = [DateTime]::new({self.last_write_time.year}, {self.last_write_time.month}, {self.last_write_time.day}, {self.last_write_time.hour}, {self.last_write_time.minute}, {self.last_write_time.second})
    $accessDate = [DateTime]::new({self.last_access_time.year}, {self.last_access_time.month}, {self.last_access_time.day}, {self.last_access_time.hour}, {self.last_access_time.minute}, {self.last_access_time.second})
    
    Write-Host "目标创建时间: $creationDate"
    Write-Host "目标修改时间: $writeDate"
    Write-Host "目标访问时间: $accessDate"
}}
catch {{
    Write-Host "创建日期对象失败: $_" -ForegroundColor Red
    exit 2
}}

# 设置文件时间属性
try {{
    Set-ItemProperty -Path $file -Name CreationTime -Value $creationDate -ErrorAction Stop
    Set-ItemProperty -Path $file -Name LastWriteTime -Value $writeDate -ErrorAction Stop
    Set-ItemProperty -Path $file -Name LastAccessTime -Value $accessDate -ErrorAction Stop
    
    Write-Host "文件时间属性已成功修改!" -ForegroundColor Green
    exit 0
}}
catch {{
    Write-Host "修改文件时间失败: $_" -ForegroundColor Red
    exit 3
}}
"""
        return script
    
    def _save_script_to_tempfile(self, script_content: str) -> str:
        """保存脚本到临时文件"""
        with tempfile.NamedTemporaryFile(suffix='.ps1', delete=False) as temp:
            temp.write(script_content.encode('utf-8'))
            self.temp_script = temp.name
        return self.temp_script
    
    def _get_execution_policy(self) -> Optional[str]:
        """获取当前执行策略"""
        if not self.is_windows:
            return None
            
        try:
            result = subprocess.run(
                ['powershell', '-Command', 'Get-ExecutionPolicy'],
                capture_output=True, text=True, check=True
            )
            return result.stdout.strip()
        except:
            return None
    
    def _set_execution_policy(self, policy: str) -> bool:
        """设置执行策略"""
        if not self.is_windows:
            return False
            
        try:
            subprocess.run(
                ['powershell', '-Command', f'Set-ExecutionPolicy {policy} -Scope CurrentUser -Force'],
                check=True
            )
            return True
        except:
            return False
    
    def _bypass_execution_policy(self) -> bool:
        """临时绕过执行策略限制"""
        if not self.is_windows:
            return False
            
        self.original_execution_policy = self._get_execution_policy()
        if self.original_execution_policy:
            # 临时设置为Bypass
            if self._set_execution_policy('Bypass'):
                self.execution_policy_bypassed = True
                return True
        return False
    
    def _restore_execution_policy(self) -> bool:
        """恢复原始执行策略"""
        if not self.is_windows or not self.execution_policy_bypassed or not self.original_execution_policy:
            return False
            
        return self._set_execution_policy(self.original_execution_policy)
    
    def apply(self) -> Tuple[bool, str]:
        """
        应用设置的时间到文件
        
        返回:
            tuple: (success: bool, output: str)
        """
        if not self.is_windows:
            return False, "此功能仅支持Windows系统"
        
        # 创建PowerShell脚本
        ps_script = self._create_powershell_script()
        script_path = self._save_script_to_tempfile(ps_script)
        
        # 尝试绕过执行策略
        self._bypass_execution_policy()
        
        try:
            # 运行PowerShell脚本
            result = subprocess.run(
                ['powershell', '-ExecutionPolicy', 'Bypass', '-File', script_path],
                capture_output=True, text=True, check=True
            )
            success = result.returncode == 0
            return success, result.stdout
        except subprocess.CalledProcessError as e:
            return False, f"执行错误: {e.stderr}"
        finally:
            # 清理临时文件
            if self.temp_script and os.path.exists(self.temp_script):
                os.remove(self.temp_script)
            
            # 恢复执行策略
            self._restore_execution_policy()
    
    def set_all_times_to(self, target_time: Union[datetime.datetime, str]) -> None:
        """
        设置所有时间属性为同一时间
        
        参数:
            target_time (datetime/str): 目标时间
        """
        parsed_time = self._parse_time(target_time) if isinstance(target_time, str) else target_time
        self.creation_time = parsed_time
        self.last_write_time = parsed_time
        self.last_access_time = parsed_time
    
    def __str__(self) -> str:
        """返回类的字符串表示"""
        return (
            f"FileTimeSetter for: {self.file_path}\n"
            f"  Creation Time: {self.creation_time.strftime('%Y-%m-%d %H:%M:%S')}\n"
            f"  Last Write Time: {self.last_write_time.strftime('%Y-%m-%d %H:%M:%S')}\n"
            f"  Last Access Time: {self.last_access_time.strftime('%Y-%m-%d %H:%M:%S')}"
        )
    
    def __del__(self):
        """析构函数，确保清理"""
        if self.temp_script and os.path.exists(self.temp_script):
            os.remove(self.temp_script)
        if self.execution_policy_bypassed:
            self._restore_execution_policy()

class FileAssociation:
    """根据一个文件路径来确认所关联的exe文件，最后结果存储在exe_path里"""
    def __init__(self, file_path):
        self.file_path = file_path
        self.extension = os.path.splitext(file_path)[1].lower()  # 获取文件扩展名
        self.exe_path = self._get_associated_exe()
    
    def _get_associated_exe(self):
        """获取文件关联的exe路径"""
        # 非Windows系统不支持
        if sys.platform != 'win32':
            raise NotImplementedError("File association only supported on Windows")
        
        # 无扩展名的文件无法关联
        if not self.extension:
            return None
        
        try:
            # 1. 获取文件类型
            with winreg.OpenKey(winreg.HKEY_CLASSES_ROOT, self.extension) as key:
                file_type = winreg.QueryValue(key, None)
            
            # 2. 获取关联的应用程序命令
            command_path = f"{file_type}\\shell\\open\\command"
            with winreg.OpenKey(winreg.HKEY_CLASSES_ROOT, command_path) as key:
                command = winreg.QueryValue(key, None)
            
            # 3. 清理命令字符串
            exe_path = self._clean_command(command)
            return exe_path
        
        except WindowsError:
            return None  # 找不到关联程序
    
    def _clean_command(self, command):
        """从命令行字符串中提取干净的exe路径"""
        # 去除环境变量
        expanded = os.path.expandvars(command)
        
        # 提取第一个可执行文件部分
        if expanded.startswith('"'):
            end = expanded.find('"', 1)
            exe_path = expanded[1:end] if end != -1 else expanded.split()[0]
        else:
            exe_path = expanded.split()[0]
        
        return exe_path
    
class fs:
    """根据一个文件路径来确认所关联的exe文件，最后结果存储在exe_path里"""
    def __init__(self, file_path):
        self.file_path = file_path
        self.extension = os.path.splitext(file_path)[1].lower()  # 获取文件扩展名
        self.exe_path = self._get_associated_exe()
    
    def _get_associated_exe(self):
        """获取文件关联的exe路径"""
        # 非Windows系统不支持
        if sys.platform != 'win32':
            raise NotImplementedError("File association only supported on Windows")
        
        # 无扩展名的文件无法关联
        if not self.extension:
            return None
        
        try:
            # 1. 获取文件类型
            with winreg.OpenKey(winreg.HKEY_CLASSES_ROOT, self.extension) as key:
                file_type = winreg.QueryValue(key, None)
            
            # 2. 获取关联的应用程序命令
            command_path = f"{file_type}\\shell\\open\\command"
            with winreg.OpenKey(winreg.HKEY_CLASSES_ROOT, command_path) as key:
                command = winreg.QueryValue(key, None)
            
            # 3. 清理命令字符串
            exe_path = self._clean_command(command)
            return exe_path
        
        except WindowsError:
            return None  # 找不到关联程序
    
    def _clean_command(self, command):
        """从命令行字符串中提取干净的exe路径"""
        # 去除环境变量
        expanded = os.path.expandvars(command)
        
        # 提取第一个可执行文件部分
        if expanded.startswith('"'):
            end = expanded.find('"', 1)
            exe_path = expanded[1:end] if end != -1 else expanded.split()[0]
        else:
            exe_path = expanded.split()[0]
        
        return exe_path

if __name__ == "__main__":
    message.showinfo("Title","Message\nmsg")
    response = request.get('https://codinghou.cn', timeout=5)
    print(f"Status: {response.status_code}")
    print(f"Content: {response.text[:200]}...")
    if not path.exists("PATH"):
        pass

    else:
        print(htyy)

    if platform == "windows":
        print("system is windows.")

    elif platform == "linux":
        print("system is linux.")
    
    elif platform == "darwin":
        print("system is macos.")

    else:
        print(platform)
    


import os
import json
import platform

class Config:
    CONFIG_FILE = os.path.expanduser("~/.kms_activator/config.json")
    
    DEFAULT_CONFIG = {
        "kms_port": 1688,
        "kms_server": "127.0.0.1",
        "auto_start_server": True,
        "vlmcsd_path": "",
        "log_level": "INFO"
    }
    
    def __init__(self):
        os.makedirs(os.path.dirname(self.CONFIG_FILE), exist_ok=True)
        self.config = self._load_config()
        
    def _load_config(self):
        if os.path.exists(self.CONFIG_FILE):
            try:
                with open(self.CONFIG_FILE, 'r') as f:
                    return json.load(f)
            except:
                return self.DEFAULT_CONFIG.copy()
        return self.DEFAULT_CONFIG.copy()
    
    def save(self):
        with open(self.CONFIG_FILE, 'w') as f:
            json.dump(self.config, f, indent=2)
    
    def get(self, key):
        return self.config.get(key, self.DEFAULT_CONFIG.get(key, None))
    
    def set(self, key, value):
        self.config[key] = value
        self.save()
    
    @property
    def system_platform(self):
        return platform.system().lower()
    
    @property
    def architecture(self):
        arch = platform.machine().lower()
        if 'x86_64' in arch or 'amd64' in arch:
            return 'x64'
        elif 'x86' in arch or 'i386' in arch:
            return 'x86'
        elif 'arm' in arch:
            return 'arm'
        return 'unknown'
    
config = Config()


import os
import re
import winreg
from .utils import run_command, logger
from .config import config

class Activator:
    def __init__(self):
        self.server_ip = config.get('kms_server')
        self.port = config.get('kms_port')
        self.kms_address = f"{self.server_ip}:{self.port}"
    
    def activate_windows(self):
        """激活Windows系统"""
        logger.info("Activating Windows...")
        
        # 设置KMS服务器
        cmd = ['cscript', '//Nologo', os.path.expandvars('%SystemRoot%\\System32\\slmgr.vbs'), 
               '/skms', self.kms_address]
        retcode, stdout, stderr = run_command(cmd, admin=True)
        
        if retcode != 0:
            logger.error(f"Failed to set KMS server: {stderr or stdout}")
            return False
        
        # 激活Windows
        cmd = ['cscript', '//Nologo', os.path.expandvars('%SystemRoot%\\System32\\slmgr.vbs'), '/ato']
        retcode, stdout, stderr = run_command(cmd, admin=True)
        
        if retcode == 0 and "successfully" in stdout:
            logger.info("Windows activated successfully")
            return True
        else:
            logger.error(f"Windows activation failed: {stderr or stdout}")
            return False
    
    def get_office_installations(self):
        """获取已安装的Office版本"""
        office_versions = []
        
        try:
            # 查找32位Office
            key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, 
                                r"SOFTWARE\Microsoft\Office")
            
            for i in range(winreg.QueryInfoKey(key)[0]):
                version = winreg.EnumKey(key, i)
                if re.match(r"\d+\.\d+", version):
                    try:
                        subkey = winreg.OpenKey(key, f"{version}\\Common\\InstallRoot")
                        path = winreg.QueryValueEx(subkey, "Path")[0]
                        office_versions.append({
                            "version": version,
                            "path": path,
                            "bitness": "32-bit"
                        })
                    except:
                        continue
        
        except FileNotFoundError:
            pass
        
        try:
            # 查找64位Office
            key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, 
                                r"SOFTWARE\WOW6432Node\Microsoft\Office")
            
            for i in range(winreg.QueryInfoKey(key)[0]):
                version = winreg.EnumKey(key, i)
                if re.match(r"\d+\.\d+", version):
                    try:
                        subkey = winreg.OpenKey(key, f"{version}\\Common\\InstallRoot")
                        path = winreg.QueryValueEx(subkey, "Path")[0]
                        office_versions.append({
                            "version": version,
                            "path": path,
                            "bitness": "64-bit"
                        })
                    except:
                        continue
        
        except FileNotFoundError:
            pass
        
        return office_versions
    
    def activate_office(self, version=None):
        """激活Microsoft Office"""
        logger.info("Activating Microsoft Office...")
        
        installations = self.get_office_installations()
        if not installations:
            logger.error("No Office installations found")
            return False
        
        # 如果未指定版本，激活所有找到的Office
        if not version:
            success = True
            for office in installations:
                if not self._activate_single_office(office):
                    success = False
            return success
        
        # 激活指定版本的Office
        for office in installations:
            if office["version"] == version:
                return self._activate_single_office(office)
        
        logger.error(f"Office version {version} not found")
        return False
    
    def _activate_single_office(self, office_info):
        """激活单个Office安装"""
        version = office_info["version"]
        path = office_info["path"]
        bitness = office_info["bitness"]
        
        logger.info(f"Activating Office {version} ({bitness}) at {path}")
        
        # 查找ospp.vbs脚本
        ospp_path = os.path.join(path, "OSPP.VBS")
        if not os.path.exists(ospp_path):
            logger.error(f"ospp.vbs not found in {path}")
            return False
        
        # 设置KMS服务器
        cmd = ['cscript', '//Nologo', ospp_path, '/sethst:', self.server_ip]
        retcode, stdout, stderr = run_command(cmd, admin=True)
        
        if retcode != 0:
            logger.error(f"Failed to set KMS server for Office: {stderr or stdout}")
            return False
        
        # 激活Office
        cmd = ['cscript', '//Nologo', ospp_path, '/act']
        retcode, stdout, stderr = run_command(cmd, admin=True)
        
        if retcode == 0 and "successful" in stdout:
            logger.info(f"Office {version} activated successfully")
            return True
        else:
            logger.error(f"Office activation failed: {stderr or stdout}")
            return False
    
    def check_activation_status(self):
        """检查激活状态"""
        results = {}
        
        # 检查Windows激活状态
        cmd = ['cscript', '//Nologo', os.path.expandvars('%SystemRoot%\\System32\\slmgr.vbs'), '/xpr']
        retcode, stdout, stderr = run_command(cmd)
        
        if retcode == 0:
            results['windows'] = stdout.strip()
        else:
            results['windows'] = f"Error: {stderr or stdout}"
        
        # 检查Office激活状态
        installations = self.get_office_installations()
        office_status = {}
        
        for office in installations:
            ospp_path = os.path.join(office["path"], "OSPP.VBS")
            if os.path.exists(ospp_path):
                cmd = ['cscript', '//Nologo', ospp_path, '/dstatus']
                retcode, stdout, stderr = run_command(cmd)
                
                if retcode == 0:
                    # 提取激活信息
                    status = "Not activated"
                    if "---LICENSED---" in stdout:
                        status = "Activated"
                    elif "---NOTIFICATIONS---" in stdout:
                        status = "Grace period"
                    
                    office_status[office["version"]] = status
                else:
                    office_status[office["version"]] = f"Error: {stderr or stdout}"
        
        results['office'] = office_status
        
        return results


import os
import sys
import subprocess
import logging
import requests
import zipfile
import tarfile
from pathlib import Path
from .config import Config

config = Config()

def get_logger(name):
    logger = logging.getLogger(name)
    logger.setLevel(config.get('log_level'))
    
    if not logger.handlers:
        ch = logging.StreamHandler()
        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
        ch.setFormatter(formatter)
        logger.addHandler(ch)
    
    return logger

logger = get_logger(__name__)

def run_command(cmd, admin=False):
    """运行系统命令"""
    try:
        if admin and sys.platform == 'win32':
            cmd = f"powershell Start-Process -Verb RunAs -Wait -FilePath '{cmd[0]}' -ArgumentList '{' '.join(cmd[1:])}'"
            process = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        else:
            process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        
        stdout, stderr = process.communicate()
        return process.returncode, stdout.decode('utf-8', 'ignore'), stderr.decode('utf-8', 'ignore')
    except Exception as e:
        logger.error(f"Command execution failed: {e}")
        return -1, "", str(e)

import os
import sys
import subprocess
import logging
import requests
import zipfile
import tarfile
import certifi
from pathlib import Path
from tqdm import tqdm
from requests.adapters import HTTPAdapter
from urllib3.util.retry import Retry
from .config import config

logger = logging.getLogger(__name__)

def download_file(url, dest_path):
    """下载文件并显示进度条"""
    try:
        # 创建带重试机制的会话
        session = requests.Session()
        retry_strategy = Retry(
            total=3,
            backoff_factor=1,
            status_forcelist=[429, 500, 502, 503, 504],
            allowed_methods=["GET"]
        )
        adapter = HTTPAdapter(max_retries=retry_strategy)
        session.mount("https://", adapter)
        
        # 使用证书验证
        response = session.get(url, stream=True, verify=certifi.where())
        response.raise_for_status()
        
        # 获取文件总大小（字节）
        total_size = int(response.headers.get('content-length', 0))
        
        # 创建进度条
        progress_bar = tqdm(
            total=total_size, 
            unit='iB', 
            unit_scale=True, 
            desc=f"下载 {os.path.basename(dest_path)}",
            bar_format='{l_bar}{bar}| {n_fmt}/{total_fmt} [{elapsed}<{remaining}, {rate_fmt}{postfix}]'
        )
        
        # 分块写入文件
        with open(dest_path, 'wb') as f:
            for chunk in response.iter_content(chunk_size=8192):
                if chunk:  # 过滤掉保持连接的新块
                    f.write(chunk)
                    progress_bar.update(len(chunk))
        
        # 关闭进度条
        progress_bar.close()
        
        # 验证文件大小
        if total_size != 0 and progress_bar.n != total_size:
            logger.error("下载不完整")
            return False
        
        return True
    except Exception as e:
        logger.error(f"下载失败: {e}")
        logger.info("尝试使用不验证证书的方式下载...")
        
        # 尝试不使用证书验证
        try:
            session = requests.Session()
            retry_strategy = Retry(total=3, backoff_factor=1)
            adapter = HTTPAdapter(max_retries=retry_strategy)
            session.mount("https://", adapter)
            
            response = session.get(url, stream=True, verify=False)
            response.raise_for_status()
            
            # 获取文件总大小（字节）
            total_size = int(response.headers.get('content-length', 0))
            
            # 创建进度条
            progress_bar = tqdm(
                total=total_size, 
                unit='iB', 
                unit_scale=True, 
                desc=f"备用下载 {os.path.basename(dest_path)}",
                bar_format='{l_bar}{bar}| {n_fmt}/{total_fmt} [{elapsed}<{remaining}, {rate_fmt}{postfix}]'
            )
            
            with open(dest_path, 'wb') as f:
                for chunk in response.iter_content(chunk_size=8192):
                    if chunk:
                        f.write(chunk)
                        progress_bar.update(len(chunk))
            
            progress_bar.close()
            
            # 验证文件大小
            if total_size != 0 and progress_bar.n != total_size:
                logger.error("下载不完整")
                return False
            
            return True
        except Exception as e2:
            logger.error(f"备用下载方式失败: {e2}")
            return False

def extract_archive(file_path, extract_dir):
    """解压文件"""
    try:
        if file_path.endswith('.zip'):
            with zipfile.ZipFile(file_path, 'r') as zip_ref:
                zip_ref.extractall(extract_dir)
        elif file_path.endswith('.tar.gz') or file_path.endswith('.tgz'):
            with tarfile.open(file_path, 'r:gz') as tar_ref:
                tar_ref.extractall(extract_dir)
        return True
    except Exception as e:
        logger.error(f"Extraction failed: {e}")
        return False

def get_binary_dir():
    """获取二进制文件目录"""
    module_dir = Path(__file__).parent.parent
    bin_dir = module_dir / 'bin' / config.system_platform / config.architecture
    bin_dir.mkdir(parents=True, exist_ok=True)
    return bin_dir

def get_vlmcsd_path():
    """获取vlmcsd路径"""
    config_path = config.get('vlmcsd_path')
    if config_path and os.path.exists(config_path):
        return config_path
    
    bin_dir = get_binary_dir()
    
    # 尝试查找已存在的二进制文件
    binary_name = "vlmcsd.exe" if sys.platform == "win32" else "vlmcsd"
    binary_path = bin_dir / binary_name
    
    if binary_path.exists():
        return str(binary_path)
    
    # 如果没有找到，尝试下载
    if not download_vlmcsd():
        return None
    
    return str(binary_path)

def download_vlmcsd():
    """下载vlmcsd二进制文件"""
    logger.info("Downloading vlmcsd binary...")
    
    base_url = "https://github.com/Wind4/vlmcsd/releases/download/svn1113/binaries.tar.gz"
    temp_dir = Path.home() / ".kms_activator" / "temp"
    temp_dir.mkdir(parents=True, exist_ok=True)
    
    archive_path = temp_dir / "binaries.tar.gz"
    
    if not download_file(base_url, archive_path):
        return False
    
    if not extract_archive(archive_path, temp_dir):
        return False
    
    # 找到对应的二进制文件
    bin_dir = get_binary_dir()
    platform_name = config.system_platform
    arch_name = config.architecture
    
    # 在解压目录中查找对应平台的二进制文件
    source_dir = temp_dir / "binaries" / platform_name.capitalize()
    if not source_dir.exists():
        logger.error(f"Unsupported platform: {platform_name}")
        return False
    
    # 根据架构选择文件
    if platform_name == "windows":
        binary_name = f"vlmcsd-{arch_name}.exe"
    else:
        binary_name = f"vlmcsd-{arch_name}-musl-static"
    
    source_path = None
    for root, _, files in os.walk(source_dir):
        for file in files:
            if file == binary_name:
                source_path = Path(root) / file
                break
    
    if not source_path:
        logger.error(f"Binary not found: {binary_name}")
        return False
    
    # 复制到目标目录
    target_path = bin_dir / ("vlmcsd.exe" if platform_name == "windows" else "vlmcsd")
    source_path.rename(target_path)
    
    # 设置可执行权限
    if platform_name != "windows":
        os.chmod(target_path, 0o755)
    
    # 更新配置
    config.set('vlmcsd_path', str(target_path))
    
    logger.info(f"vlmcsd downloaded to {target_path}")
    return True


r"""
cl /LD /EHsc /I "D:\Python\include" 
/I "D:\Python\Lib\site-packages\pybind11\include"   
C:\Users\36376\Desktop\pynativegui.cpp /link /LIBPATH:"D:\Python\libs"     
python311.lib user32.lib gdi32.lib comdlg32.lib
"""

import typing as t

def create_window(
    title: str = "Window",
    width: int = 400,
    height: int = 300,
    no_titlebar: bool = False,
    transparent: bool = False,
    resizable: bool = True,
    topmost: bool = False
) -> t.Any: 
    """
    Create a new window
    Creates a top-level application window
    
    Args:
        title: Window title bar text
        width: Initial window width in pixels
        height: Initial window height in pixels
        no_titlebar: Create borderless window without title bar
        transparent: Enable window transparency
        resizable: Allow user to resize window
        topmost: Keep window always on top of others
    
    Returns:
        Window capsule object reference
    
    创建新窗口
    创建顶层应用程序窗口
    
    参数:
        title: 窗口标题栏文本
        width: 初始窗口宽度（像素）
        height: 初始窗口高度（像素）
        no_titlebar: 创建无标题栏的无边框窗口
        transparent: 启用窗口透明效果
        resizable: 允许用户调整窗口大小
        topmost: 窗口始终保持在最上层
    """
    ...

def show_window(window: t.Any) -> None:
    """
    Display a created window
    Makes a previously created window visible on screen
    
    Args:
        window: Window capsule object reference
    
    显示已创建的窗口
    使先前创建的窗口在屏幕上可见
    
    参数:
        window: 窗口胶囊对象引用
    """
    ...

def set_window_title(window: t.Any, title: str) -> None:
    """
    Set window title text
    Updates the text displayed in window's title bar
    
    Args:
        window: Window capsule object reference
        title: New title text
    
    设置窗口标题文本
    更新窗口标题栏显示的文本
    
    参数:
        window: 窗口胶囊对象引用
        title: 新标题文本
    """
    ...

def set_window_size(window: t.Any, width: int, height: int) -> None:
    """
    Resize application window
    Changes dimensions of specified window
    
    Args:
        window: Window capsule object reference
        width: New window width in pixels
        height: New window height in pixels
    
    调整应用程序窗口大小
    更改指定窗口的尺寸
    
    参数:
        window: 窗口胶囊对象引用
        width: 新窗口宽度（像素）
        height: 新窗口高度（像素）
    """
    ...

def set_window_position(window: t.Any, x: int, y: int) -> None:
    """
    Reposition application window
    Moves window to new screen coordinates
    
    Args:
        window: Window capsule object reference
        x: New horizontal position (pixels from left)
        y: New vertical position (pixels from top)
    
    重新定位应用程序窗口
    将窗口移动到新的屏幕坐标
    
    参数:
        window: 窗口胶囊对象引用
        x: 新水平位置（距离左侧的像素数）
        y: 新垂直位置（距离顶部的像素数）
    """
    ...

def set_window_alpha(window: t.Any, alpha: int) -> None:
    """
    Set window transparency level
    Adjusts overall opacity of the window (0-255)
    
    Args:
        window: Window capsule object reference
        alpha: Transparency value (0=fully transparent, 255=opaque)
    
    设置窗口透明度级别
    调整窗口的整体不透明度（0-255）
    
    参数:
        window: 窗口胶囊对象引用
        alpha: 透明度值（0=完全透明，255=不透明）
    """
    ...

def create_label(
    parent: t.Any,
    text: str = "",
    x: int = 0,
    y: int = 0,
    width: int = 100,
    height: int = 20,
    anchor: str = "nw"
) -> t.Any:
    """
    Create text label control
    Displays static text in application window
    
    Args:
        parent: Parent window capsule object
        text: Label content text
        x: Horizontal position in parent
        y: Vertical position in parent
        width: Label width in pixels
        height: Label height in pixels
        anchor: Text anchoring position
    
    Returns:
        Label capsule object reference
    
    创建文本标签控件
    在应用程序窗口中显示静态文本
    
    参数:
        parent: 父窗口胶囊对象
        text: 标签内容文本
        x: 在父容器中的水平位置
        y: 在父容器中的垂直位置
        width: 标签宽度（像素）
        height: 标签高度（像素）
        anchor: 文本锚定位置
    """
    ...

def create_button(
    parent: t.Any,
    text: str = "Button",
    x: int = 0,
    y: int = 0,
    width: int = 80,
    height: int = 24,
    command: t.Optional[t.Callable] = None
) -> t.Any:
    """
    Create clickable button control
    Executes callback function when clicked
    
    Args:
        parent: Parent window capsule object
        text: Button display text
        x: Horizontal position in parent
        y: Vertical position in parent
        width: Button width in pixels
        height: Button height in pixels
        command: Click event callback function
    
    Returns:
        Button capsule object reference
    
    创建可点击按钮控件
    点击时执行回调函数
    
    参数:
        parent: 父窗口胶囊对象
        text: 按钮显示文本
        x: 在父容器中的水平位置
        y: 在父容器中的垂直位置
        width: 按钮宽度（像素）
        height: 按钮高度（像素）
        command: 点击事件回调函数
    """
    ...

def create_entry(
    parent: t.Any,
    default_text: str = "",
    x: int = 0,
    y: int = 0,
    width: int = 120,
    height: int = 24
) -> t.Any:
    """
    Create text entry field
    Single-line user input control
    
    Args:
        parent: Parent window capsule object
        default_text: Initial field content
        x: Horizontal position in parent
        y: Vertical position in parent
        width: Field width in pixels
        height: Field height in pixels
    
    Returns:
        Entry capsule object reference
    
    创建文本输入框
    单行用户输入控件
    
    参数:
        parent: 父窗口胶囊对象
        default_text: 初始字段内容
        x: 在父容器中的水平位置
        y: 在父容器中的垂直位置
        width: 输入框宽度（像素）
        height: 输入框高度（像素）
    """
    ...

def get_entry_text(entry: t.Any) -> str:
    """
    Retrieve text from entry field
    Gets current content of text input control
    
    Args:
        entry: Entry capsule object reference
    
    Returns:
        Current text content
    
    从输入框获取文本
    获取文本输入控件的当前内容
    
    参数:
        entry: 输入框胶囊对象引用
    
    返回:
        当前文本内容
    """
    ...

def set_control_text(control: t.Any, text: str) -> None:
    """
    Update control display text
    Changes text content of various controls
    
    Args:
        control: Control capsule object reference
        text: New text content
    
    更新控件显示文本
    更改各种控件的文本内容
    
    参数:
        control: 控件胶囊对象引用
        text: 新文本内容
    """
    ...

def create_listbox(
    parent: t.Any,
    x: int = 0,
    y: int = 0,
    width: int = 200,
    height: int = 150
) -> t.Any:
    """
    Create selection list control
    Displays scrollable list of items
    
    Args:
        parent: Parent window capsule object
        x: Horizontal position in parent
        y: Vertical position in parent
        width: Listbox width in pixels
        height: Listbox height in pixels
    
    Returns:
        Listbox capsule object reference
    
    创建选择列表控件
    显示可滚动的项目列表
    
    参数:
        parent: 父窗口胶囊对象
        x: 在父容器中的水平位置
        y: 在父容器中的垂直位置
        width: 列表框宽度（像素）
        height: 列表框高度（像素）
    """
    ...

def listbox_insert(listbox: t.Any, index: int, text: str) -> None:
    """
    Add item to listbox
    Inserts text item at specified position
    
    Args:
        listbox: Listbox capsule object reference
        index: Insertion position (0-based)
        text: Item display text
    
    向列表框中添加项目
    在指定位置插入文本项目
    
    参数:
        listbox: 列表框胶囊对象引用
        index: 插入位置（从0开始）
        text: 项目显示文本
    """
    ...

def create_combobox(
    parent: t.Any,
    x: int = 0,
    y: int = 0,
    width: int = 120,
    height: int = 100
) -> t.Any:
    """
    Create dropdown selection control
    Combines text field with drop-down list
    
    Args:
        parent: Parent window capsule object
        x: Horizontal position in parent
        y: Vertical position in parent
        width: Combobox width in pixels
        height: Combobox height in pixels
    
    Returns:
        Combobox capsule object reference
    
    创建下拉选择控件
    组合文本框和下拉列表
    
    参数:
        parent: 父窗口胶囊对象
        x: 在父容器中的水平位置
        y: 在父容器中的垂直位置
        width: 组合框宽度（像素）
        height: 组合框高度（像素）
    """
    ...

def combobox_add(combobox: t.Any, text: str) -> None:
    """
    Add option to combobox
    Appends item to dropdown list
    
    Args:
        combobox: Combobox capsule object reference
        text: Option display text
    
    向组合框添加选项
    将项目追加到下拉列表
    
    参数:
        combobox: 组合框胶囊对象引用
        text: 选项显示文本
    """
    ...

def create_progressbar(
    parent: t.Any,
    x: int = 0,
    y: int = 0,
    width: int = 200,
    height: int = 20,
    orient: int = 0
) -> t.Any:
    """
    Create progress indicator
    Visual representation of task completion
    
    Args:
        parent: Parent window capsule object
        x: Horizontal position in parent
        y: Vertical position in parent
        width: Progressbar width in pixels
        height: Progressbar height in pixels
        orient: Orientation (0=horizontal, 1=vertical)
    
    Returns:
        Progressbar capsule object reference
    
    创建进度指示器
    任务完成进度的可视化表示
    
    参数:
        parent: 父窗口胶囊对象
        x: 在父容器中的水平位置
        y: 在父容器中的垂直位置
        width: 进度条宽度（像素）
        height: 进度条高度（像素）
        orient: 方向（0=水平，1=垂直）
    """
    ...

def progress_set(progressbar: t.Any, value: int) -> None:
    """
    Update progress indicator
    Sets current progress percentage (0-100)
    
    Args:
        progressbar: Progressbar capsule object reference
        value: Completion percentage
    
    更新进度指示器
    设置当前进度百分比（0-100）
    
    参数:
        progressbar: 进度条胶囊对象引用
        value: 完成百分比
    """
    ...

def create_canvas(
    parent: t.Any,
    x: int = 0,
    y: int = 0,
    width: int = 300,
    height: int = 200,
    bg: str = "white"
) -> t.Any:
    """
    Create drawing surface
    Provides area for custom graphics rendering
    
    Args:
        parent: Parent window capsule object
        x: Horizontal position in parent
        y: Vertical position in parent
        width: Canvas width in pixels
        height: Canvas height in pixels
        bg: Background color name
    
    Returns:
        Canvas capsule object reference
    
    创建绘图表面
    提供自定义图形渲染区域
    
    参数:
        parent: 父窗口胶囊对象
        x: 在父容器中的水平位置
        y: 在父容器中的垂直位置
        width: 画布宽度（像素）
        height: 画布高度（像素）
        bg: 背景颜色名称
    """
    ...

def canvas_line(
    canvas: t.Any,
    x1: int,
    y1: int,
    x2: int,
    y2: int,
    color: str = "black",
    width: int = 1
) -> None:
    """
    Draw line on canvas
    Renders straight line between two points
    
    Args:
        canvas: Canvas capsule object reference
        x1: Starting X coordinate
        y1: Starting Y coordinate
        x2: Ending X coordinate
        y2: Ending Y coordinate
        color: Line color name
        width: Line thickness in pixels
    
    在画布上绘制直线
    在两点之间渲染直线
    
    参数:
        canvas: 画布胶囊对象引用
        x1: 起始X坐标
        y1: 起始Y坐标
        x2: 结束X坐标
        y2: 结束Y坐标
        color: 线条颜色名称
        width: 线条粗细（像素）
    """
    ...

def canvas_rectangle(
    canvas: t.Any,
    x1: int,
    y1: int,
    x2: int,
    y2: int,
    outline: str = "black",
    fill: str = "",
    width: int = 1
) -> None:
    """
    Draw rectangle on canvas
    Renders rectangular shape with optional fill
    
    Args:
        canvas: Canvas capsule object reference
        x1: Top-left X coordinate
        y1: Top-left Y coordinate
        x2: Bottom-right X coordinate
        y2: Bottom-right Y coordinate
        outline: Border color name
        fill: Fill color name (empty for transparent)
        width: Border thickness in pixels
    
    在画布上绘制矩形
    渲染矩形形状（可选填充）
    
    参数:
        canvas: 画布胶囊对象引用
        x1: 左上角X坐标
        y1: 左上角Y坐标
        x2: 右下角X坐标
        y2: 右下角Y坐标
        outline: 边框颜色名称
        fill: 填充颜色名称（空表示透明）
        width: 边框粗细（像素）
    """
    ...

def canvas_text(
    canvas: t.Any,
    x: int,
    y: int,
    text: str,
    color: str = "black",
    font: str = "Arial",
    size: int = 12
) -> None:
    """
    Draw text on canvas
    Renders specified text at given position
    
    Args:
        canvas: Canvas capsule object reference
        x: Text baseline X coordinate
        y: Text baseline Y coordinate
        text: String content to render
        color: Text color name
        font: Font family name
        size: Font size in points
    
    在画布上绘制文本
    在指定位置渲染文本
    
    参数:
        canvas: 画布胶囊对象引用
        x: 文本基线X坐标
        y: 文本基线Y坐标
        text: 要渲染的字符串内容
        color: 文本颜色名称
        font: 字体名称
        size: 字体大小（磅值）
    """
    ...

def create_menu(window: t.Any) -> t.Any:
    """
    Create menu container
    Prepares menu structure for window
    
    Args:
        window: Window capsule object reference
    
    Returns:
        Menu capsule object reference
    
    创建菜单容器
    为窗口准备菜单结构
    
    参数:
        window: 窗口胶囊对象引用
    """
    ...

def menu_add_item(
    menu: t.Any,
    label: str,
    callback: t.Callable,
    accelerator: str = ""
) -> None:
    """
    Add command to menu
    Appends clickable item to menu container
    
    Args:
        menu: Menu capsule object reference
        label: Menu item display text
        callback: Click event handler
        accelerator: Keyboard shortcut hint
    
    向菜单添加命令项
    将可点击项目添加到菜单容器
    
    参数:
        menu: 菜单胶囊对象引用
        label: 菜单项显示文本
        callback: 点击事件处理函数
        accelerator: 键盘快捷键提示
    """
    ...

def add_menu(window: t.Any, menu: t.Any, label: str) -> None:
    """
    Attach menu to window
    Adds menu container to window's menu bar
    
    Args:
        window: Window capsule object reference
        menu: Menu capsule object reference
        label: Menu display text
    
    将菜单附加到窗口
    将菜单容器添加到窗口的菜单栏
    
    参数:
        window: 窗口胶囊对象引用
        menu: 菜单胶囊对象引用
        label: 菜单显示文本
    """
    ...

def create_statusbar(window: t.Any) -> None:
    """
    Create status bar
    Adds information panel to window bottom
    
    Args:
        window: Window capsule object reference
    
    创建状态栏
    在窗口底部添加信息面板
    
    参数:
        window: 窗口胶囊对象引用
    """
    ...

def statusbar_set(
    window: t.Any,
    part: int,
    text: str
) -> None:
    """
    Update status bar text
    Sets content for specified status bar section
    
    Args:
        window: Window capsule object reference
        part: Status bar segment index
        text: Text content to display
    
    更新状态栏文本
    设置指定状态栏部分的内容
    
    参数:
        window: 窗口胶囊对象引用
        part: 状态栏分段索引
        text: 要显示的文本内容
    """
    ...

def bind(
    control: t.Any,
    event_name: str,
    callback: t.Callable
) -> None:
    """
    Bind event to control
    Attaches event handler to UI component
    
    Args:
        control: Control capsule object reference
        event_name: Event identifier string
        callback: Event handler function
    
    Supported events:
        "<Button-1>"      : Mouse button press
        "<ButtonRelease-1>": Mouse button release
        "<Motion>"        : Mouse movement
        "<Key>"           : Keyboard key press
        "<Configure>"     : Control resize
        "<FocusIn>"       : Control gains focus
        "<FocusOut>"      : Control loses focus
    
    将事件绑定到控件
    将事件处理函数附加到UI组件
    
    参数:
        control: 控件胶囊对象引用
        event_name: 事件标识字符串
        callback: 事件处理函数
    
    支持的事件:
        "<Button-1>"      : 鼠标按钮按下
        "<ButtonRelease-1>": 鼠标按钮释放
        "<Motion>"        : 鼠标移动
        "<Key>"           : 键盘按键
        "<Configure>"     : 控件调整大小
        "<FocusIn>"       : 控件获得焦点
        "<FocusOut>"      : 控件失去焦点
    """
    ...

def filedialog(
    title: str = "Open File",
    filetypes: str = "All Files\0*.*\0",
    initialdir: str = "",
    save: bool = False
) -> t.Optional[str]:
    """
    Show file selection dialog
    Opens system file chooser interface
    
    Args:
        title: Dialog window title
        filetypes: File filter patterns
        initialdir: Starting directory path
        save: True for save dialog, False for open
    
    Returns:
        Selected file path or None
    
    显示文件选择对话框
    打开系统文件选择器界面
    
    参数:
        title: 对话框窗口标题
        filetypes: 文件过滤模式
        initialdir: 起始目录路径
        save: True为保存对话框，False为打开对话框
    
    返回:
        选择的文件路径或None
    """
    ...

def colorchooser(
    initial_color: t.Optional[t.Tuple[int, int, int]] = None
) -> t.Optional[t.Tuple[int, int, int]]:
    """
    Show color selection dialog
    Opens system color picker interface
    
    Args:
        initial_color: Preselected RGB color tuple
    
    Returns:
        Selected RGB color tuple or None
    
    显示颜色选择对话框
    打开系统颜色选择器界面
    
    参数:
        initial_color: 预选的RGB颜色元组
    
    返回:
        选择的RGB颜色元组或None
    """
    ...

def messagebox(
    title: str,
    message: str,
    type: str = "info"
) -> t.Optional[bool]:
    """
    Display message dialog
    Shows system alert with buttons
    
    Args:
        title: Dialog window title
        message: Information text content
        type: Dialog type ("info", "warning", "error", "question")
    
    Returns:
        For question dialogs: True=Yes, False=No
        For other types: None
    
    显示消息对话框
    显示带按钮的系统警报
    
    参数:
        title: 对话框窗口标题
        message: 信息文本内容
        type: 对话框类型 ("info", "warning", "error", "question")
    
    返回:
        对于问题对话框: True=是, False=否
        其他类型: None
    """
    ...

def mainloop() -> None:
    """
    Start application event loop
    Begins processing user interface events
    
    启动应用程序事件循环
    开始处理用户界面事件
    """
    ...

def quit() -> None:
    """
    Terminate application
    Exits program and closes all windows
    
    终止应用程序
    退出程序并关闭所有窗口
    """
    ...

def set_window_icon(window: t.Any, icon_path: str) -> None:
    """
    Set window title bar icon
    Loads and displays custom icon in window title bar
    
    Args:
        window: Window capsule object reference
        icon_path: Path to .ico icon file
    
    Supported formats:
        .ico files (recommended)
        .exe files with icon resources
        .dll files with icon resources
    
    Note: For best results, provide icons in multiple sizes:
        - 16x16 (small/taskbar)
        - 32x32 (standard)
        - 48x48 (large)
        - 256x256 (high DPI)
    
    设置窗口标题栏图标
    加载并显示自定义图标在窗口标题栏
    
    参数:
        window: 窗口胶囊对象引用
        icon_path: .ico图标文件路径
    
    支持格式:
        .ico 文件 (推荐)
        包含图标资源的 .exe 文件
        包含图标资源的 .dll 文件
    
    注意: 为获得最佳效果，请提供多种尺寸的图标:
        - 16x16 (小尺寸/任务栏)
        - 32x32 (标准尺寸)
        - 48x48 (大尺寸)
        - 256x256 (高DPI)
    """
    ...